==> bbwa-0.0.4.tar.gz: bbwa-0.0.4/thumb.php <==
<?php
//
// BBWA
// thumb.php
// ̥ɥɽ
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA : ThumbView</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">
<link rel="stylesheet" type="text/css" href="default.css">
</head>
<body class="top">
<table border="0" width="100%" class="top"
  cellspacing="0" cellpadding="0">
<tr><td nowrap>


<?php
include("variables.php");

// 
$tempArray = array();
$dirHandle = opendir($dirName);
switch ($_GET['order']) {
  case 1:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        array_push($tempArray, $fileList);
      }
    }
    rsort($tempArray);
    $fileArray = $tempArray;
    break;
  case 2:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        array_push($tempArray, $fileList);
      }
    }
    sort($tempArray);
    $fileArray = $tempArray;
    break;
  default:
    while ($fileList = readdir($dirHandle)) { 
      if (eregi("\.jpg|\.png|\.gif$", $fileList)) {
        $tempArray[$fileList] =
          filemtime("${dirName}Messages/${fileList}_mes.txt");
      }
    }
    arsort($tempArray);
    $fileArray = array_keys($tempArray);
}
closedir($dirHandle);

// ڡ׻
//$pages = (int) ((count($fileArray) - 1) / $perPage + 1);
//if ($_GET['page'] == "end") {
//  $current = $pages;
//} else {
//  $current = min($_GET['page'], $pages);
//}
//$imgStart = ($current - 1) * $perPage;
//$imgEnd = min(($imgStart + $perPage), count($fileArray));

$imgStart = 0;
$imgEnd = count($fileArray);

print("᡼: " . count($fileArray));
?>


&nbsp;&nbsp;
<a href="JavaScript:location.reload()">
<img src="Icons/icon_refresh.png" border="0" align="absmiddle">ɹ</a>
&nbsp;&nbsp;
<a href="JavaScript:window.close()">
<img src="Icons/icon_close.png" border="0" align="absmiddle">Ĥ</a>
</td></tr></table>
<table border="0" align="center" style="margin:5px;">


<?php
if (count($fileArray) > 0) {
  $counter = 0;
  for ($i = $imgStart; $i < $imgEnd; $i++) {
    if ($counter % 5 == 0) {
      print("<tr><td align=\"center\" class=\"photoframe\">");
    } else {
      print("<td align=\"center\" class=\"photoframe\">");
    }

    // ɤ߹
    $message = file("${dirName}Messages/${fileArray[$i]}_mes.txt");
    $pizza = htmlspecialchars($message[0]);
    $piece = explode("|||", $pizza);

    if (mb_strlen($piece[2]) > 10) {
      $piece[2] = mb_substr($piece[2], 0, 9) . "";
    }
    if (mb_strlen($piece[3]) > 10) {
      $piece[3] = mb_substr($piece[3], 0, 9) . "";
    }

    // ͥɽ
    print("<a href=\"right.php?img=${fileArray[$i]}&order=${_GET['order']}\"" .
       "target=\"RIGHT\" onClick=\"JavaScript:opener.focus()\">");
    if (eregi("\.gif$", $fileArray[$i])) {
      print("<img src=\"${picUrl}${fileArray[$i]}\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"><br>");
    } else {
      print("<img src=\"${picUrl}Thumbnails/${fileArray[$i]}_thumb.jpg\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"><br>");
    }
    print("<div class=\"thumb\">̾: ${piece[2]}<br>" .
      "̾: ${piece[3]}<br>" .
      "ȿ: " . (count($message) - 1));
    if (time() - filemtime("${dirName}Messages/${fileArray[$i]}_mes.txt") <
      86400) {
      print(" <img src=\"Icons/icon_fresh.png\" border=\"0\"
        align=\"absmiddle\" alt=\"NEW\">");
    }
    print("</div>");
    print("</a>");

    if ($counter % 5 == 4) {
      print("</td></tr>\n");
    } else {
      print("</td>\n");
    }
    $counter++;
  }
} else {
  print("<tr><td align=\"center\">NO IMAGE!</td></tr>");
}
?>


</table>
</body>
</html>

==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/thumb.php <==
<?php
//
// BBWA
// thumb.php
// ̥ɥɽ
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>BBWA : ThumbView</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php

echo <<<EOD
<link rel="stylesheet" type="text/css" href="Themes/${theme}.css">
<script language="JavaScript">
<!--
tWidth = ((${thumbSize} + 15) * 5) + 60;
sWidth = Math.min(tWidth, screen.width * 0.8);
sHeight = screen.height * 0.8;
window.resizeTo(sWidth, sHeight);
EOD;

?>


function sortSelect(sf) {
  if (sf.ss.selectedIndex == 0) {
    location.href = 'thumb.php?order=0';
  } else if (sf.ss.selectedIndex == 1) {
    location.href = 'thumb.php?order=1';
  } else if (sf.ss.selectedIndex == 2) {
    location.href = 'thumb.php?order=2';
  }
}
// -->
</script>
</head>
<body class="top">
<table border="0" width="100%" class="top"
  cellspacing="0" cellpadding="0">
<tr><td nowrap>


<?php
// ǥåɤ߹
$tempArray = array();
$filePtr = fopen("${dirName}INDEX", "r");
while ($pizza = fgets($filePtr, 1024)) {
  $piece = explode("|||", $pizza);
  $tempArray[$piece[0]] = $piece[1];
}
switch ($_GET['order']) {
  case 1:
    krsort($tempArray);
    $selected = array("", "selected", "");
    break;
  case 2:
    ksort($tempArray);
    $selected = array("", "", "selected");
    break;
  default:
    arsort($tempArray);
    $selected = array("selected", "", "");
}
$fileArray = array_keys($tempArray);
fclose($filePtr);

// ڡ׻
//$pages = (int) ((count($fileArray) - 1) / $perPage + 1);
//if ($_GET['page'] == "END") {
//  $current = $pages;
//} else {
//  $current = min($_GET['page'], $pages);
//}
//$imgStart = ($current - 1) * $perPage;
//$imgEnd = min(($imgStart + $perPage), count($fileArray));

$imgStart = 0;
$imgEnd = count($fileArray);
?>


<form class="top" name="sf">
¤ؤ
<select class="top" name="ss" align="absmiddle"
  onChange="sortSelect(this.form)">


<?php

echo <<<EOD
<option ${selected[0]}>ͥ
<option ${selected[1]}>ͥ
<option ${selected[2]}>ͥ(Ť)
EOD;

?>


</select>
&nbsp;&nbsp;
<a href="JavaScript:window.close()">
<img src="Icons/icon_close.png" border="0" align="absmiddle">Ĥ</a>
&nbsp;&nbsp;
<a href="JavaScript:opener.focus()">
<img src="Icons/icon_main.png" border="0" align="absmiddle">ᥤ</a>
&nbsp;&nbsp;


<?php
print("᡼: " . count($fileArray));
?>


</form>
</td></tr></table>
<table border="0" cellspacing="5" align="center" style="margin:5px;">


<?php
if (count($fileArray) > 0) {
  $counter = 0;
  for ($i = $imgStart; $i < $imgEnd; $i++) {
    if ($counter % 5 == 0) {
      print("<tr><td align=\"center\" class=\"photoframe\">");
    } else {
      print("<td align=\"center\" class=\"photoframe\">");
    }

    // ɤ߹
    $message = file("${dirName}Messages/${fileArray[$i]}_mes.txt");
    $pizza = htmlspecialchars($message[0]);
    $piece = explode("|||", $pizza);

    if (mb_strlen($piece[2]) > 10) {
      $piece[2] = mb_substr($piece[2], 0, 9) . "";
    }
    if (mb_strlen($piece[3]) > 10) {
      $piece[3] = mb_substr($piece[3], 0, 9) . "";
    }

    // ͥɽ
    print("<a href=\"right.php?img=${fileArray[$i]}\"" .
       "target=\"RIGHT\" onClick=\"JavaScript:opener.focus()\">");
    if (eregi("\.gif$", $fileArray[$i])) {
      print("<img src=\"${picUrl}${fileArray[$i]}\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"><br>");
    } else {
      print("<img src=\"${picUrl}Thumbnails/${fileArray[$i]}_thumb.jpg\"" .
        "border=\"0\" width=\"${piece[0]}\" height=\"${piece[1]}\"><br>");
    }
    print("<div class=\"thumb\">̾: ${piece[2]}<br>" .
      "̾: ${piece[3]}<br>" .
      "ȿ: " . (count($message) - 1));
    if (time() - filemtime("${dirName}Messages/${fileArray[$i]}_mes.txt") <
      86400) {
      print(" <img src=\"Icons/icon_fresh.png\" border=\"0\"
        align=\"absmiddle\" alt=\"NEW\">");
    }
    print("</div>");
    print("</a>");

    if ($counter % 5 == 4) {
      print("</td></tr>\n");
    } else {
      print("</td>\n");
    }
    $counter++;
  }
} else {
  print("<tr><td align=\"center\">NO IMAGE!</td></tr>");
}
?>


</table>
</body>
</html>
